"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getChildrenKey = void 0;
const cli_ux_1 = require("cli-ux");
const path = require("path");
const fs = require("fs");
const searchIssues_1 = require("../jira/searchIssues");
const id_1 = require("../misc/id");
// Taking a query such as `type = Initiative`,
// this will return all issue key matching this query and
// all children of tickets in this query
const getChildrenKey = async (jiraConfig, jql, cacheDir, useCache = false) => {
    const issueKeys = [];
    const cachePath = path.join(cacheDir, 'children');
    const cacheFile = path.join(cachePath, `${(0, id_1.getId)(jql)}-${new Date().toJSON().slice(0, 10)}.json`);
    fs.mkdirSync(cachePath, { recursive: true });
    if (useCache === true && fs.existsSync(cacheFile)) {
        cli_ux_1.cli.log(`Getting issues from cache: ${cacheFile}`);
        const cacheData = fs.readFileSync(cacheFile, {
            encoding: 'utf8',
            flag: 'r',
        });
        const issueKeys = JSON.parse(cacheData);
        console.log(`Collected: ${issueKeys.length} issues from cache`);
        return issueKeys;
    }
    cli_ux_1.cli.log(`Collecting children using JQL: ${jql} issues`);
    const issuesJira = await (0, searchIssues_1.default)(jiraConfig, jql, 'key,summary');
    if (issuesJira.length === 0) {
        return [];
    }
    cli_ux_1.cli.log(`Will be collecting children of: ${issuesJira.length} issues`);
    for (const si of issuesJira) {
        if (issueKeys.find(i => i.key === si.key) === undefined) {
            issueKeys.push({ key: si.key, parent: { key: '', summary: '' } });
        }
        // Get all child issues for issues returned in the first query
        cli_ux_1.cli.action.start(`Fetching child issues of: ${si.key}`);
        const childIssues = await (0, searchIssues_1.default)(jiraConfig, 'issuekey in childIssuesOf(' + si.key + ')', 'key');
        if (childIssues.length > 0) {
            cli_ux_1.cli.action.stop(` done - ${childIssues.length} issues`);
            for (const ckey of childIssues.map((i) => i.key)) {
                if (issueKeys.find(i => i.key === ckey) === undefined) {
                    issueKeys.push({
                        key: ckey,
                        parent: { key: si.key, summary: si.fields.summary },
                    });
                }
            }
        }
        else {
            cli_ux_1.cli.action.stop(` done - 0 issues`);
        }
    }
    console.log(`Fetched: ${issueKeys.length} issues`);
    console.log(`Saving data to cache: ${cacheFile}`);
    const controlFileStream = fs.createWriteStream(cacheFile, {
        encoding: 'utf8',
        flags: 'w',
    });
    controlFileStream.write(JSON.stringify(issueKeys));
    controlFileStream.end();
    return issueKeys;
};
exports.getChildrenKey = getChildrenKey;
